@@ -84,7 +84,7 @@ void KIPI::Plugin::setup( TQWidget* widget )
     d->m_defaultWidget = widget;
     d->m_actions.insert( widget, TDEActionPtrList() );
     TQString name = TQString( "action collection for %1" ).arg( widget->name() );
-    d->m_actionCollection.insert( widget, new TDEActionCollection( widget, TQT_TQOBJECT(widget), name.latin1(), d->m_instance ) );
+    d->m_actionCollection.insert( widget, new TDEActionCollection( widget, widget, name.latin1(), d->m_instance ) );
 }
 
 
